



library(changeS)
set.seed(42)
# Simulate data
n <- 500
changepoint_index <- 334

y <- vector(length = n)
y[1:changepoint_index] <- rnorm(changepoint_index, mean = 10, sd = 2)
y[(changepoint_index + 1):n] <- rnorm(n + 1 - changepoint_index, mean = 12.5, sd = 2)

# Create data frame
d <- data.frame(x = seq(1, n), y = y)

# Fit the model
fit <- fitS(d, xColIndex = 1, yColIndex = 2)
std_error <- summary(fit$nlsOut)$coefficient[,"Std. Error"][[4]]
changepoint <- summary(fit$nlsOut)$coefficient[,"Estimate"][[4]]
preMean <- fit$pars['preMean']
postMean <- fit$pars['postMean']

# Create plot
plot(fit)
title("Changepoint Detection: Simulated Data")
mtext("Abrupt Changepoint", side = 3, line = .5, cex = 0.8)
abline(v = changepoint, col = rgb(0, 100, 0, maxColorValue = 255), lty = 2)
text(changepoint, preMean-3, labels = paste("est. changepoint:", round(changepoint, 2)), col = rgb(0, 100, 0, maxColorValue = 255))
text(changepoint - 40, max(d$y) - 1.5, 
     labels = paste("(Std. Error: ", round(std_error, 2), ")", sep = ""), 
     col = "purple")

# Overlay preMean and postMean
text(changepoint - 50, preMean-1, labels = paste("preMean:", round(preMean, 2)), col = "blue")
text(changepoint + 50, postMean+1, labels = paste("postMean:", round(postMean, 2)), col = "red")
