library(changeS)
library(foreach)
library(doParallel)

# preMean==10, postMean==12.5

totalCores = detectCores()
cluster <- makeCluster(totalCores[1]-1)
registerDoParallel(cluster)

n <- 1000
mean1 <- 10
mean2 <- 12.5
trueChangePt2 <-round(n*2/3)

# Our method  (expect cpt 667)
our_test <- foreach(i = 1:100, .combine=rbind, .packages=c("changeS", "segmented")) %dopar% {
  # Generate the dataset
  x <- 1:n
  y <- vector(length=n)
  y[1:trueChangePt2] <- rt(trueChangePt2, 3) + mean1 # 0 centered T-dist + 10
  y[(trueChangePt2+1):n] <- rt(n-trueChangePt2, 3) + mean2  # T + 12.5
  d <- data.frame(x=x,y=y)
  # Our fit
  our_temp <- fitS(d, 1, 2, depth=1)
  # Segmented
  seg_model <- lm(y~x, data=d)
  external_pkg <- segmented(obj=seg_model, npsi=c(2))
  
  c(abs(our_temp$pars[[4]]-trueChangePt2), abs(mean(external_pkg$psi[,"Est."])-trueChangePt2), 
    our_temp$pars[[4]], mean(external_pkg$psi[,"Est."]))
}

stopCluster(cluster)

# Find the mean abs distance
print("Mean changepoint found for fitS: ")
mean(our_test[,3])
print("Mean absolute distance for fitS: ")
mean(our_test[,1])  # ours

print("Mean changepoint found for Segmented: ")
mean(our_test[,4])
print("Mean absolute distance for Segmented: ")
mean(our_test[,2])  # theirs


