library(changeS)
library(foreach)
library(doParallel)

# preMean==10, postMean==12.5

totalCores = detectCores()
cluster <- makeCluster(totalCores[1]-1)
registerDoParallel(cluster)

n <- 1000
mean1 <- 10
mean2 <- 12.5
trueChangePt1 <- round(n/4)
trueChangePt2 <-round(n*2/3)

# Our method  (expect cpts to be at 250, 667)
our_test <- foreach(i = 1:100, .combine=rbind, .packages=c("changeS", "segmented")) %dopar% {
  x <- 1:n
  y <- vector(length=n)
  y[1:trueChangePt1] <- rnorm(trueChangePt1,mean1,2)
  y[(trueChangePt1+1):trueChangePt2] <- seq(from=mean1, to=mean2,
                                            length.out=trueChangePt2-trueChangePt1) + rnorm(n=trueChangePt2-trueChangePt1, sd=2)
  y[(trueChangePt2+1):n] <- rnorm(n-trueChangePt2,mean2,2)
  d <- data.frame(x=x,y=y)
  our_temp <- fitS(d, 1, 2, depth=2)
  seg_model <- lm(y~x, data=d)
  external_pkg <- segmented(obj=seg_model, npsi=c(2))
  our_diff_1 <- abs(our_temp$leftPartition$pars[[4]] - trueChangePt1)
  our_diff_2 <- abs(our_temp$rightPartition$pars[[4]] - trueChangePt2)
  external_diff_1 <- abs(external_pkg$psi["psi1.x","Est."] - trueChangePt1)
  external_diff_2 <- abs(external_pkg$psi["psi2.x","Est."] - trueChangePt2)
  c(our_diff_1, our_diff_2, external_diff_1, external_diff_2)
}

stopCluster(cluster)

# Find average absolute diffs
mean(our_test[,1])  # ours
mean(our_test[,2])

mean(our_test[,3])  # theirs
mean(our_test[,4])
